.. _sync:

=======================
Syncing your project
=======================

| Syncing is supposed to integrate any changes to the QUBE templates back into your already existing project.
| Due to the inherent complexity of this task, it is **not yet implemented**. However, discussions and contributions are very welcome!
